import apiFetch from "@/lib/api-fetch";
import type Application from "@/lib/api/entities/application";
import { defineStore } from "pinia";
import { ref } from "vue";

const localStorageKey = "vulpine-oauth-app";

export const useAppStore = defineStore("oauth-app", () => {
	const json = localStorage.getItem(localStorageKey);
	const app = ref<Application>(json ? JSON.parse(json) : undefined);

	async function getApp() {
		if (app.value) return app.value;

		const resp = await apiFetch<Application>("/api/v1/apps", {
			method: "POST",
			body: {
				client_name: "vulpine-fe",
				redirect_uris: `${window.location.origin}/auth/callback`,
				scopes: "read write follow push",
			},
		});
		app.value = resp;
		localStorage.setItem(localStorageKey, JSON.stringify(resp));
		return app.value;
	}

	return { app, getApp };
});
